@@ -33,3 +33,7 @@
 #undef HAVE_PTY_H
 #undef HAVE_UTIL_H
 #undef HAVE_SENDMSG
+#undef NEED_DECLARATION_SCANDIR
+#undef HAVE_IMLIB_1_9
+
+#undef WITH_SYMBOL_UNDERSCORE
