@@ -4,7 +4,22 @@
  *
  */
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#  include <config.h>
+#endif
+
+/* AIX requires this to be the first thing in the file.  */
+#ifndef __GNUC__
+# if HAVE_ALLOCA_H
+#  include <alloca.h>
+# else
+#  ifdef _AIX
+ #pragma alloca
+#  else
+#   ifndef alloca /* predefined by HP cc +Olibcalls */
+char *alloca ();
+#   endif
+#  endif
+# endif
 #endif
 
 #include <glib.h>
@@ -16,10 +31,6 @@
 #include <string.h>
 #include <sys/wait.h>
 
-#ifdef HAVE_ALLOCA_H
-#include <alloca.h>
-#endif
-
 #include "gnome-defs.h"
 #include "gnome-help.h"
 #include "gnome-i18nP.h"
@@ -112,8 +123,9 @@ gnome_help_file_path(gchar *app, gchar *path)
  * gnome_help_display:
  * @ignore: value of this is ignored.  To simplify hooking into clicked
  *          signals
- *
- * Cause a help viewer to display help entry defined in ref.
+ * @ref: A GnomeHelpMenuEntry.
+ * 
+ * Cause a help viewer to display help entry defined in @ref.
  */
 void
 gnome_help_display (void *ignore, GnomeHelpMenuEntry *ref)
@@ -141,6 +153,7 @@ gnome_help_display (void *ignore, GnomeHelpMenuEntry *ref)
  * @ignore: ignored.
  * @page_num: The number of the current notebook page in the
  * properties box.
+ * @ref: A GnomeHelpMenuEntry
  *
  * Cause a help viewer to display the help entry defined in ref.  This
  * function is meant to be connected to the "help" signal of a
@@ -173,6 +186,39 @@ gnome_help_pbox_display (void *ignore, gint page_num, GnomeHelpMenuEntry *ref)
 	gnome_help_goto (ignore, url);
 }
 
+/**
+ * gnome_help_pbox_goto
+ * @ignore: ignored.
+ * @ignore2: also ignored.
+ * @ref: A GnomeHelpMenuEntry
+ *
+ * Cause a help viewer to display the help entry defined in @ref.  This
+ * function is meant to be connected to the help button of a
+ * GnomePropertyBox, when you don't want any munging of the help path
+ * done.  Most of the time, you can use gnome_help_pbox_display,
+ * though.
+ */
+void
+gnome_help_pbox_goto (void *ignore, int ignore2, GnomeHelpMenuEntry *ref)
+{
+        gchar *file, *url;
+
+	g_assert(ref != NULL);
+	g_assert(ref->path != NULL);
+	g_assert(ref->name != NULL);
+
+	file = gnome_help_file_path (ref->name, ref->path);
+	if (file == NULL)
+	  return;
+	
+	url = alloca (strlen (file)+10);
+	strcpy (url, "file:");
+	strcat (url, file);
+	g_free (file);
+	
+	gnome_help_goto (ignore, url);
+}
+
 /**
  * gnome_help_goto:
  * @ignore: ignored.
