@@ -325,11 +325,6 @@ static gchar *menu_names[] =
 /* Creates a pixmap appropriate for items.  The window parameter is required 
  * by gnome-stock (bleah) */
 
-/**
- * create_pixmap:
- * @GtkWidget *window:  
- */
-
 static GtkWidget *
 create_pixmap (GtkWidget *window, GnomeUIPixmapType pixmap_type, 
 		gpointer pixmap_info)
@@ -484,7 +479,7 @@ install_menuitem_hint_to_statusbar(GnomeUIInfo* uiinfo, GtkStatusbar* bar)
     {
       gtk_object_set_data (GTK_OBJECT(uiinfo->widget),
                            "apphelper_statusbar_hint",
-                           uiinfo->hint);
+                           L_(uiinfo->hint));
 
       gtk_signal_connect (GTK_OBJECT (uiinfo->widget),
                           "select",
@@ -498,6 +493,16 @@ install_menuitem_hint_to_statusbar(GnomeUIInfo* uiinfo, GtkStatusbar* bar)
     }
 }
 
+
+/**
+ * gnome_app_install_statusbar_menu_hints
+ * @bar: Pointer to Gtk+ status bar object
+ * @uiinfo: Gnome UI info for the menu to be changed
+ *
+ * Description:
+ * Install menu hints for the given status bar.
+ */
+
 void 
 gnome_app_install_statusbar_menu_hints (GtkStatusbar* bar,
                                         GnomeUIInfo* uiinfo)
@@ -580,7 +585,7 @@ install_menuitem_hint_to_appbar(GnomeUIInfo* uiinfo, GnomeAppBar* bar)
     {
       gtk_object_set_data (GTK_OBJECT(uiinfo->widget),
                            "apphelper_appbar_hint",
-                           uiinfo->hint);
+                           L_(uiinfo->hint));
 
       gtk_signal_connect (GTK_OBJECT (uiinfo->widget),
                           "select",
@@ -594,6 +599,17 @@ install_menuitem_hint_to_appbar(GnomeUIInfo* uiinfo, GnomeAppBar* bar)
     }
 }
 
+
+/**
+ * gnome_app_ui_configure_configurable
+ * @uiinfo: Pointer to GNOME UI menu/toolbar info
+ * 
+ * Description:
+ * Configure all user-configurable elements in the given UI info 
+ * structure.  This includes loading and setting previously-set options from
+ * GNOME config files.
+ */
+
 void
 gnome_app_ui_configure_configurable (GnomeUIInfo* uiinfo)
 {
@@ -669,6 +685,16 @@ gnome_app_ui_configure_configurable (GnomeUIInfo* uiinfo)
   }
 }
 
+
+/**
+ * gnome_app_install_appbar_menu_hints
+ * @appbar: Pointer to GNOME app bar object.
+ * @uiinfo: GNOME UI info for menu
+ *
+ * Description:
+ * Install menu hints for the given GNOME app bar object.
+ */
+
 void
 gnome_app_install_appbar_menu_hints (GnomeAppBar* appbar,
                                      GnomeUIInfo* uiinfo)
@@ -708,6 +734,16 @@ gnome_app_install_appbar_menu_hints (GnomeAppBar* appbar,
 	}
 }
 
+
+/**
+ * gnome_app_install_menu_hints
+ * @app: Pointer to GNOME app object
+ * @uiinfo: GNOME UI menu for which hints will be set
+ *
+ * Description:
+ * Set menu hints for the GNOME app object's attached status bar.
+ */
+
 void
 gnome_app_install_menu_hints (GnomeApp *app,
                               GnomeUIInfo *uiinfo) {
@@ -735,28 +771,14 @@ create_menu_item (GnomeUIInfo *uiinfo, int is_radio, GSList **radio_group,
 {
 	GtkWidget *label;
 	GtkWidget *pixmap;
-	char *i8l_label;
 	guint keyval;
-	gboolean use_gnome_libs_catalog;
 	int type;
 	
 	/* Translate configurable menu items to normal menu items. */
 
-	if (uiinfo->type == GNOME_APP_UI_ITEM_CONFIGURABLE) {
-		int type = uiinfo->accelerator_key;
-		
+	if (uiinfo->type == GNOME_APP_UI_ITEM_CONFIGURABLE)
 	        gnome_app_ui_configure_configurable( uiinfo );
 
-		if (type == GNOME_APP_CONFIGURABLE_ITEM_NEW)
-			use_gnome_libs_catalog = 0;
-		else
-			use_gnome_libs_catalog = 1;
-	} else
-		use_gnome_libs_catalog = 0;
-
-	if (uiinfo->type == GNOME_APP_UI_SUBTREE_STOCK)
-		use_gnome_libs_catalog = 1;
-	
 	/* Create the menu item */
 
 	switch (uiinfo->type) {
@@ -818,21 +840,11 @@ create_menu_item (GnomeUIInfo *uiinfo, int is_radio, GSList **radio_group,
 	/* Don't use gettext on the empty string since gettext will map
 	 * the empty string to the header at the beginning of the .pot file. */
 
-	if (uiinfo->label [0] == '\0')
-		i8l_label = "";
-	else
-	{
-#ifdef ENABLE_NLS
-		if (use_gnome_libs_catalog)
-			i8l_label = dgettext (PACKAGE, uiinfo->label);
-		else
-			i8l_label = gettext (uiinfo->label);
-#else
-		i8l_label = uiinfo->label;
-#endif
-	}
-	
-	label = create_label (i8l_label, &keyval);
+	label = create_label ( uiinfo->label [0] == '\0'?
+			       "":(uiinfo->type == GNOME_APP_UI_SUBTREE_STOCK ?
+				   D_(uiinfo->label):L_(uiinfo->label)),
+			       &keyval);
+
 	gtk_container_add (GTK_CONTAINER (uiinfo->widget), label);
 
 	gtk_accel_label_set_accel_widget (GTK_ACCEL_LABEL (label), 
@@ -1438,8 +1450,8 @@ create_toolbar_item (GtkToolbar *toolbar, GnomeUIInfo *uiinfo, int is_radio,
 						    type,
 						    is_radio ? 
 						    *radio_group : NULL,
-						    _(uiinfo->label),
-						    _(uiinfo->hint),
+						    L_(uiinfo->label),
+						    L_(uiinfo->hint),
 						    NULL,
 						    pixmap,
 						    NULL,
@@ -2097,18 +2109,18 @@ gnome_app_insert_menus_interp (GnomeApp *app, gchar *path,
 	gnome_app_insert_menus_custom(app, path, menuinfo, &uidata);
 }
 
+#ifdef ENABLE_NLS
 char *
 gnome_app_helper_gettext (char *str)
 {
 	char *s;
 
-#ifdef ENABLE_NLS
-	s = dgettext (PACKAGE, str);
-#else
-	s = str;
-#endif
+        s = gettext (str);
+	if ( s == str )
+	        s = dgettext (PACKAGE, str);
 
 	return s;
 }
+#endif
 
 
