@@ -949,7 +949,10 @@ gil_destroy (GtkObject *object)
 	gil->dirty  = TRUE;
 	gnome_icon_list_clear (gil);
 
-	gtk_object_unref (GTK_OBJECT (gil->adj));
+	if (gil->adj)
+		gtk_object_unref (GTK_OBJECT (gil->adj));
+	if (gil->hadj)
+		gtk_object_unref (GTK_OBJECT (gil->hadj));
 	
 	if (GTK_OBJECT_CLASS (parent_class)->destroy)
 		(*GTK_OBJECT_CLASS (parent_class)->destroy) (object);
@@ -1252,7 +1255,7 @@ gil_button_press (GtkWidget *widget, GdkEventButton *event)
 
 	v = (*GTK_WIDGET_CLASS (parent_class)->button_press_event) (widget, event);
 
-	if (v)
+	if (v || event->button != 1)
 		return TRUE;
 
 	if (gil->selection_mode != GTK_SELECTION_MULTIPLE)
@@ -1261,19 +1264,18 @@ gil_button_press (GtkWidget *widget, GdkEventButton *event)
 	if (gil->sel_rect)     /* Already selecting */
 	        return FALSE;
 
-	gnome_canvas_window_to_world (
-		GNOME_CANVAS (gil),
-		event->x, event->y, 
-		&gil->sel_start_x, &gil->sel_start_y);
+	gnome_canvas_window_to_world (GNOME_CANVAS (gil),
+				      event->x, event->y, 
+				      &gil->sel_start_x, &gil->sel_start_y);
 
 	/*
 	 * If the Shift or control keys are pressed, then keep a list
 	 * of the current selection
 	 */
-	if (event->state & (GDK_SHIFT_MASK|GDK_CONTROL_MASK)){
+	if (event->state & (GDK_SHIFT_MASK|GDK_CONTROL_MASK)) {
 		GList *l = NULL;
 
-		for (l = gil->selection; l; l = l->next){
+		for (l = gil->selection; l; l = l->next) {
 			void *data = l->data;
 			
 			gil->preserve_selection = g_list_prepend (gil->preserve_selection, data);
@@ -1281,20 +1283,20 @@ gil_button_press (GtkWidget *widget, GdkEventButton *event)
 	}
 
 	stipple = gdk_bitmap_create_from_data (NULL, gray50_bits, gray50_width, gray50_height);
-	gil->sel_rect = gnome_canvas_item_new (
-		gnome_canvas_root (GNOME_CANVAS (gil)),
-		gnome_canvas_rect_get_type (),
-		"x1", (double) event->x,
-		"y1", (double) event->y,
-		"x2", (double) event->x,
-		"y2", (double) event->y,
-		"outline_color", "black",
-		"width_pixels", 1,
-		"outline_stipple", stipple,
-		NULL);
+	gil->sel_rect = gnome_canvas_item_new (gnome_canvas_root (GNOME_CANVAS (gil)),
+					       gnome_canvas_rect_get_type (),
+					       "x1", (double) event->x,
+					       "y1", (double) event->y,
+					       "x2", (double) event->x,
+					       "y2", (double) event->y,
+					       "outline_color", "black",
+					       "width_pixels", 1,
+					       "outline_stipple", stipple,
+					       NULL);
 	gdk_bitmap_unref (stipple);
 
-	gnome_canvas_item_grab (gil->sel_rect, GDK_POINTER_MOTION_MASK | GDK_BUTTON_RELEASE_MASK, NULL, event->time);
+	gnome_canvas_item_grab (gil->sel_rect, GDK_POINTER_MOTION_MASK | GDK_BUTTON_RELEASE_MASK,
+				NULL, event->time);
 	return TRUE;
 }
 
@@ -1391,6 +1393,17 @@ gil_motion_notify (GtkWidget *widget, GdkEventMotion *event)
 	return TRUE;
 }
 
+static void
+gil_set_scroll_adjustments (GtkLayout *layout,
+			    GtkAdjustment *hadjustment,
+			    GtkAdjustment *vadjustment)
+{
+	Gil *gil = GIL (layout);
+
+	gnome_icon_list_set_hadjustment (gil, hadjustment);
+	gnome_icon_list_set_vadjustment (gil, vadjustment);
+}
+
 typedef gboolean (*xGtkSignal_BOOL__INT_POINTER) (GtkObject * object,
 						  gint     arg1,
 						  gpointer arg2,
@@ -1460,10 +1473,12 @@ gil_class_init (GilClass *gil_class)
 {
 	GtkObjectClass *object_class;
 	GtkWidgetClass *widget_class;
+	GtkLayoutClass *layout_class;
 	GnomeCanvasClass *canvas_class;
 
 	object_class = (GtkObjectClass *)   gil_class;
 	widget_class = (GtkWidgetClass *)   gil_class;
+	layout_class = (GtkLayoutClass *)   gil_class;
 	canvas_class = (GnomeCanvasClass *) gil_class;
 
 	parent_class = gtk_type_class (gnome_canvas_get_type ());
@@ -1523,6 +1538,12 @@ gil_class_init (GilClass *gil_class)
 	widget_class->button_release_event = gil_button_release;
 	widget_class->motion_notify_event  = gil_motion_notify;
 
+	/* we override GtkLayout's set_scroll_adjustments signal instead
+	 * of creating a new signal so as to keep binary compatibility.
+	 * Anyway, a widget class only needs one of these signals, and
+	 * this gives the correct implementation for GnomeIconList */
+	layout_class->set_scroll_adjustments = gil_set_scroll_adjustments;
+
 	gil_class->select_icon             = real_select_icon;
 	gil_class->unselect_icon           = real_unselect_icon;
 }
@@ -1633,8 +1654,19 @@ gnome_icon_list_set_hadjustment (GnomeIconList *gil, GtkAdjustment *hadj)
 
 	gil->hadj = hadj;
 
-	if (gil->hadj)
+	if (gil->hadj) {
 		gtk_object_ref (GTK_OBJECT (gil->hadj));
+		/* the horizontal adjustment is not used, so set some default
+		 * values to indicate that everything is visible horizontally
+		 */
+		gil->hadj->lower = 0.0;
+		gil->hadj->upper = 1.0;
+		gil->hadj->value = 0.0;
+		gil->hadj->step_increment = 1.0;
+		gil->hadj->page_increment = 1.0;
+		gil->hadj->page_size = 1.0;
+		gtk_adjustment_changed (gil->hadj);
+	}
 
 	if (!gil->hadj || !old_adjustment)
 		gtk_widget_queue_resize (GTK_WIDGET (gil));
