@@ -17,6 +17,24 @@
  * 02111-1307, USA.
  */
 
+#ifdef HAVE_CONFIG_H
+# include <config.h>
+#endif
+
+/* AIX requires this to be the first thing in the file.  */
+#ifndef __GNUC__
+# if HAVE_ALLOCA_H
+#  include <alloca.h>
+# else
+#  ifdef _AIX
+ #pragma alloca
+#  else
+#   ifndef alloca /* predefined by HP cc +Olibcalls */
+char *alloca ();
+#   endif
+#  endif
+# endif
+#endif
 
 #include <sys/types.h>
 #include <sys/wait.h>
@@ -28,14 +46,6 @@
 #include <gtk/gtk.h>
 #include <gnome.h>
 
-#ifdef HAVE_CONFIG_H
-# include <config.h>
-#endif
-
-#ifdef HAVE_ALLOCA_H
-#include <alloca.h>
-#endif
-
 #ifndef HAVE_GDK_CHILD_REGISTER
 
 /* SIGCHLD handler for gdk */
