@@ -113,6 +113,7 @@ goad_server_list_get(void)
   GoadServerList *newl;
   GHashTable *by_goad_id;
   int i;
+  char *ctmp;
 
   newl = g_new0(GoadServerList, 1);
   servinfo = g_array_new(TRUE, FALSE, sizeof(GoadServer));
@@ -128,40 +129,47 @@ goad_server_list_get(void)
     struct dirent *dent;
     
     while((dent = readdir(dirh))) {
-	    if (!strcmp(dent->d_name, ".") || !strcmp(dent->d_name, ".."))
-		    continue;
-	    
-	    g_string_sprintf(tmpstr, "=%s/%s", usersrvpath->str, dent->d_name);
-	    
-	    goad_server_list_read(tmpstr->str, servinfo, tmpstr, newl);
+      char *p;
+
+      p = strrchr (dent->d_name, '.');
+      if (!p || (strcmp (p, ".goad") != 0 && strcmp (p, ".gnorba") != 0))
+	continue;
+
+      g_string_sprintf(tmpstr, "=%s/%s", usersrvpath->str, dent->d_name);
+      goad_server_list_read(tmpstr->str, servinfo, tmpstr, newl);
     }
     closedir(dirh);
   }
   g_string_free(usersrvpath, TRUE);
   
   /* System servers */
-  dirh = opendir(GNOMESYSCONFDIR SERVER_LISTING_PATH);
+  ctmp = gnome_unconditional_config_file(SERVER_LISTING_PATH);
+  dirh = opendir(ctmp);
   if(dirh) {
     struct dirent *dent;
 
     while((dent = readdir(dirh))) {
-	    if (!strcmp(dent->d_name, ".") || !strcmp(dent->d_name, ".."))
-		    continue;
+      char *p;
 
-      g_string_sprintf(tmpstr, "=" GNOMESYSCONFDIR SERVER_LISTING_PATH "/%s",
-		       dent->d_name);
-		       
+      p = strrchr (dent->d_name, '.');
+      if (!p || (strcmp (p, ".goad") != 0 && strcmp (p, ".gnorba") != 0))
+	continue;
+
+      g_string_sprintf(tmpstr, "=" GNOMESYSCONFDIR SERVER_LISTING_PATH "/%s", dent->d_name);
       goad_server_list_read(tmpstr->str, servinfo, tmpstr, newl);
     }
     closedir(dirh);
   }
+  g_free(ctmp);
 
   goad_server_list_read(SERVER_LISTING_PATH "/", servinfo, tmpstr, newl);
 
   newl->list = (GoadServer *)servinfo->data;
-  for(i = 0; newl->list[i].repo_id; i++)
-    g_hash_table_insert(newl->by_goad_id,
-			newl->list[i].server_id, &newl->list[i]);
+  if(newl->list) {
+    for(i = 0; newl->list[i].repo_id; i++)
+      g_hash_table_insert(newl->by_goad_id,
+			  newl->list[i].server_id, &newl->list[i]);
+  }
 
   g_array_free(servinfo, FALSE);
   g_string_free(tmpstr, TRUE);
@@ -817,6 +825,7 @@ goad_server_unregister_atexit(ActiveServerInfo *ai, CORBA_Environment *ev)
   CORBA_exception_free(ev); /* Clear previous exceptions */
 
   name_service = gnome_name_service_get();
+  g_assert(name_service != CORBA_OBJECT_NIL);
 
   poa = (PortableServer_POA)CORBA_ORB_resolve_initial_references(_gnorba_gnome_orbit_orb,
 								 "RootPOA", ev);
@@ -1102,6 +1111,8 @@ goad_server_register(CORBA_Object name_server,
   if(name_server == CORBA_OBJECT_NIL)
     name_server = gnome_name_service_get();
 
+  g_assert(name_server != CORBA_OBJECT_NIL);
+
   old_server = CosNaming_NamingContext_resolve(name_server, &nom, ev);
 
   if(ev->_major == CORBA_NO_EXCEPTION) {
@@ -1167,6 +1178,8 @@ goad_server_unregister(CORBA_Object name_server,
   if(name_server == CORBA_OBJECT_NIL)
     name_server = gnome_name_service_get();
 
+  g_assert(name_server != CORBA_OBJECT_NIL);
+
   nc[2].id   = (char *)name;
   nc[2].kind = (char *)kind;
 
