@@ -312,7 +312,7 @@ zvt_term_set_blink (ZvtTerm *term, int state)
   g_return_if_fail (term != NULL);                     
   g_return_if_fail (ZVT_IS_TERM (term));
 
-  if (!(term->blink_enabled ^ state))
+  if (!(term->blink_enabled ^ (state?1:0)))
     return;
 
   if (term->blink_enabled)
@@ -489,7 +489,7 @@ zvt_term_destroy (GtkObject *object)
  * in all elements.
  *
  * The elements 0 trough 15 are the first 16 colours for the terminal,
- * with element 16 and 17 the defualt foreground and background colour
+ * with element 16 and 17 the default foreground and background colour
  * respectively.
  */
 void
@@ -2177,6 +2177,11 @@ vt_draw_text(void *user_data, int col, int row, char *text, int len, int attr)
   g_return_if_fail (widget != NULL);
   g_return_if_fail (ZVT_IS_TERM (widget));
 
+  if (!GTK_WIDGET_DRAWABLE (widget))
+    {
+      return;
+    }
+
   term = ZVT_TERM (widget);
 
   vx = term->vx;
@@ -2300,7 +2305,12 @@ vt_scroll_area(void *user_data, int firstrow, int count, int offset, int fill)
   
   g_return_if_fail (widget != NULL);
   g_return_if_fail (ZVT_IS_TERM (widget));
-  
+
+  if (!GTK_WIDGET_DRAWABLE (widget))
+    {
+      return;
+    }
+
   term = ZVT_TERM (widget);
 
   if(term->transparent || term->pixmap_filename)
@@ -2740,6 +2750,11 @@ draw_back_pixmap (GtkWidget *widget, int nx, int ny, int nw, int nh)
   g_return_if_fail (widget != NULL);
   g_return_if_fail (ZVT_IS_TERM (widget));
 
+  if (!GTK_WIDGET_DRAWABLE (widget))
+    {
+      return;
+    }
+
   term = ZVT_TERM (widget);
   bgc = term->back_gc;
   
